"""
Database configuration module for pycftools

Provides configuration parameters with environment variable defaults
"""

import os

# PostgreSQL connection parameters
POSTGRES_USER = os.getenv('POSTGRES_USER', 'postgres')
POSTGRES_PASSWORD = os.getenv('POSTGRES_PASSWORD', 'postgres') 
DB_HOST = os.getenv('DB_HOST', 'localhost')
DB_PORT = os.getenv('DB_PORT', '5432')
POSTGRES_DB = os.getenv('POSTGRES_DB', 'cellframe_db')

# Additional database configuration
DB_ECHO = os.getenv('DB_ECHO', 'False').lower() == 'true'
DB_POOL_SIZE = int(os.getenv('DB_POOL_SIZE', '5'))
DB_POOL_RECYCLE = int(os.getenv('DB_POOL_RECYCLE', '3600'))

def get_database_url() -> str:
    """
    Construct database URL from environment variables.
    
    Returns:
        PostgreSQL connection URL string
    """
    return f'postgresql://{POSTGRES_USER}:{POSTGRES_PASSWORD}@{DB_HOST}:{DB_PORT}/{POSTGRES_DB}' 